==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/HttpCookieHashKeyFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;

public class HttpCookieHashKeyFluentImpl<A extends HttpCookieHashKeyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HttpCookieHashKeyFluent<A>{

    private HTTPCookieBuilder httpCookie;

    public HttpCookieHashKeyFluentImpl(){
    }
    public HttpCookieHashKeyFluentImpl(HttpCookieHashKey instance){
            this.withHttpCookie(instance.getHttpCookie()); 
    }

    
/**
 * This method has been deprecated, please use method buildHttpCookie instead.
 * @return The buildable object.
 */
@Deprecated public HTTPCookie getHttpCookie(){
            return this.httpCookie!=null?this.httpCookie.build():null;
    }

    public HTTPCookie buildHttpCookie(){
            return this.httpCookie!=null?this.httpCookie.build():null;
    }

    public A withHttpCookie(HTTPCookie httpCookie){
            _visitables.remove(this.httpCookie);
            if (httpCookie!=null){ this.httpCookie= new HTTPCookieBuilder(httpCookie); _visitables.add(this.httpCookie);} return (A) this;
    }

    public Boolean hasHttpCookie(){
            return this.httpCookie != null;
    }

    public A withNewHttpCookie(String name,String path,Long ttl){
            return (A)withHttpCookie(new HTTPCookie(name, path, ttl));
    }

    public HttpCookieHashKeyFluent.HttpCookieNested<A> withNewHttpCookie(){
            return new HttpCookieNestedImpl();
    }

    public HttpCookieHashKeyFluent.HttpCookieNested<A> withNewHttpCookieLike(HTTPCookie item){
            return new HttpCookieNestedImpl(item);
    }

    public HttpCookieHashKeyFluent.HttpCookieNested<A> editHttpCookie(){
            return withNewHttpCookieLike(getHttpCookie());
    }

    public HttpCookieHashKeyFluent.HttpCookieNested<A> editOrNewHttpCookie(){
            return withNewHttpCookieLike(getHttpCookie() != null ? getHttpCookie(): new HTTPCookieBuilder().build());
    }

    public HttpCookieHashKeyFluent.HttpCookieNested<A> editOrNewHttpCookieLike(HTTPCookie item){
            return withNewHttpCookieLike(getHttpCookie() != null ? getHttpCookie(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HttpCookieHashKeyFluentImpl that = (HttpCookieHashKeyFluentImpl) o;
            if (httpCookie != null ? !httpCookie.equals(that.httpCookie) :that.httpCookie != null) return false;
            return true;
    }


    public class HttpCookieNestedImpl<N> extends HTTPCookieFluentImpl<HttpCookieHashKeyFluent.HttpCookieNested<N>> implements HttpCookieHashKeyFluent.HttpCookieNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final HTTPCookieBuilder builder;
    
            HttpCookieNestedImpl(HTTPCookie item){
                    this.builder = new HTTPCookieBuilder(this, item);
            }
            HttpCookieNestedImpl(){
                    this.builder = new HTTPCookieBuilder(this);
            }
    
    public N and(){
            return (N) HttpCookieHashKeyFluentImpl.this.withHttpCookie(builder.build());
    }
    public N endHttpCookie(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/HttpCookieHashKeyFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class HttpCookieHashKeyFluentImpl<A extends HttpCookieHashKeyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements HttpCookieHashKeyFluent<A>{

    private HTTPCookieBuilder httpCookie;

    public HttpCookieHashKeyFluentImpl(){
    }
    public HttpCookieHashKeyFluentImpl(HttpCookieHashKey instance){
            this.withHttpCookie(instance.getHttpCookie()); 
    }

    
/**
 * This method has been deprecated, please use method buildHttpCookie instead.
 * @return The buildable object.
 */
@Deprecated public HTTPCookie getHttpCookie(){
            return this.httpCookie!=null?this.httpCookie.build():null;
    }

    public HTTPCookie buildHttpCookie(){
            return this.httpCookie!=null?this.httpCookie.build():null;
    }

    public A withHttpCookie(HTTPCookie httpCookie){
            _visitables.get("httpCookie").remove(this.httpCookie);
            if (httpCookie!=null){ this.httpCookie= new HTTPCookieBuilder(httpCookie); _visitables.get("httpCookie").add(this.httpCookie);} return (A) this;
    }

    public Boolean hasHttpCookie(){
            return this.httpCookie != null;
    }

    public A withNewHttpCookie(String name,String path,Integer ttl){
            return (A)withHttpCookie(new HTTPCookie(name, path, ttl));
    }

    public HttpCookieHashKeyFluent.HttpCookieNested<A> withNewHttpCookie(){
            return new HttpCookieNestedImpl();
    }

    public HttpCookieHashKeyFluent.HttpCookieNested<A> withNewHttpCookieLike(HTTPCookie item){
            return new HttpCookieNestedImpl(item);
    }

    public HttpCookieHashKeyFluent.HttpCookieNested<A> editHttpCookie(){
            return withNewHttpCookieLike(getHttpCookie());
    }

    public HttpCookieHashKeyFluent.HttpCookieNested<A> editOrNewHttpCookie(){
            return withNewHttpCookieLike(getHttpCookie() != null ? getHttpCookie(): new HTTPCookieBuilder().build());
    }

    public HttpCookieHashKeyFluent.HttpCookieNested<A> editOrNewHttpCookieLike(HTTPCookie item){
            return withNewHttpCookieLike(getHttpCookie() != null ? getHttpCookie(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            HttpCookieHashKeyFluentImpl that = (HttpCookieHashKeyFluentImpl) o;
            if (httpCookie != null ? !httpCookie.equals(that.httpCookie) :that.httpCookie != null) return false;
            return true;
    }


    public class HttpCookieNestedImpl<N> extends HTTPCookieFluentImpl<HttpCookieHashKeyFluent.HttpCookieNested<N>> implements HttpCookieHashKeyFluent.HttpCookieNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final HTTPCookieBuilder builder;
    
            HttpCookieNestedImpl(HTTPCookie item){
                    this.builder = new HTTPCookieBuilder(this, item);
            }
            HttpCookieNestedImpl(){
                    this.builder = new HTTPCookieBuilder(this);
            }
    
    public N and(){
            return (N) HttpCookieHashKeyFluentImpl.this.withHttpCookie(builder.build());
    }
    public N endHttpCookie(){
            return and();
    }

}


}
